/*
 * Editor.java     1.0     2001/12/27
 *
 * Copyright (c) 2001 Andreas Dangel <a.dangel@gmx.de>
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package editor;

import java.awt.event.*;
import javax.swing.*;

public class Editor {

    static JFrame editorFrame;
    static ActionListener editorActionListener;
    static WindowListener editorWindowListener;
    static VocabularyTree vocabularyTree;

    public static void main(String[] args) {
        String filename = null;

        if (args.length == 1) {
            filename = args[0];
        } else {
	    String help;
	    help = "Usage: java editor.Editor file.xml\n"
	         + "                             |\n"
		 + "                             -> 1st argument";
            System.err.println(help);
            System.exit(1);
        }

        editorActionListener = new EditorActionListener();
        editorWindowListener = new EditorWindowListener();
        vocabularyTree = new VocabularyTree(filename);

        editorFrame = new EditorFrame(vocabularyTree);
        editorFrame.pack();
        editorFrame.show();
    }

    public static void exit() {
        /* gespeichert? */
        if (!getSaved()) {
            int response;
            response = JOptionPane.showConfirmDialog(editorFrame,
                                "Data is NOT saved! Shall I save it?",
                                "Data NOT saved",
                                JOptionPane.YES_NO_OPTION,
                                JOptionPane.QUESTION_MESSAGE);
            if (response == JOptionPane.OK_OPTION) {
                vocabularyTree.saveToFile();
            }
        }

        System.exit(0);
    }

    public static void setSaved(boolean flag) {
        ((EditorFrame) editorFrame).setSaved(flag);
    }

    public static boolean getSaved() {
        return ((EditorFrame) editorFrame).getSaved();
    }
}
