/*
 * EditorEditVocableDialog.java     1.0     2001/12/27
 *
 * Copyright (c) 2001 Andreas Dangel <a.dangel@gmx.de>
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package editor;

import libraries.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

public class EditorEditVocableDialog extends JDialog {

    Vocable vocable;

    private JPanel contentPane;

    private JPanel buttonsPanel;
    private JButton cancelButton;
    private JButton okButton;

    private JPanel centerPanel;
    private JLabel wordLabel;
    private JLabel translationsLabel;
    private JLabel remarkLabel;
    private JLabel typeLabel;
    private JLabel tagLabel;
    JTextField wordTextField;
    JTextArea translationsTextArea;
    JTextField remarkTextField;
    JComboBox typeComboBox;
    JTextField tagTextField;
    private JPanel wordPanel;
    private JPanel translationsPanel;
    private JPanel remarkPanel;
    private JPanel typePanel;
    private JPanel tagPanel;

    private ActionListener actionListener;

    private static final int TEXTFIELD_COLUMNS = 20;
    private static final int TEXTAREA_ROWS = 5;


    public EditorEditVocableDialog(Vocable voc) {
        super(Editor.editorFrame, "edit vocable");

        Editor.editorFrame.setEnabled(false);

        vocable = voc;
        actionListener = new EditorEditVocableDialogActionListener();

        cancelButton = new JButton("cancel");
        cancelButton.addActionListener(actionListener);
        okButton = new JButton("OK");
        okButton.addActionListener(actionListener);
        buttonsPanel = new JPanel();
        buttonsPanel.setLayout(new BoxLayout(buttonsPanel, BoxLayout.X_AXIS));
        buttonsPanel.add(Box.createHorizontalGlue());
        buttonsPanel.add(cancelButton);
        buttonsPanel.add(okButton);

        wordLabel = new JLabel("Word:");
        wordTextField = new JTextField(vocable.getWord(), TEXTFIELD_COLUMNS);
        wordPanel = new JPanel();
        wordPanel.add(wordLabel);
        wordPanel.add(wordTextField);

        translationsLabel = new JLabel("Translations:");
        translationsTextArea = new JTextArea(vocable.getTranslations().getText(), TEXTAREA_ROWS, TEXTFIELD_COLUMNS);
        translationsPanel = new JPanel();
        translationsPanel.setLayout(new BoxLayout(translationsPanel, BoxLayout.Y_AXIS));
        translationsPanel.add(translationsLabel);
        translationsPanel.add(translationsTextArea);

        remarkLabel = new JLabel("Remark:");
        remarkTextField = new JTextField(vocable.getRemark(), TEXTFIELD_COLUMNS);
        remarkPanel = new JPanel();
        remarkPanel.add(remarkLabel);
        remarkPanel.add(remarkTextField);

        typeLabel = new JLabel("Type:");
        typeComboBox = new JComboBox(Vocable.TYPES);
        typeComboBox.setSelectedIndex(vocable.getType());
        typePanel = new JPanel();
        typePanel.add(typeLabel);
        typePanel.add(typeComboBox);

        tagLabel = new JLabel("Tag:");
        tagTextField = new JTextField(vocable.getTag(), TEXTFIELD_COLUMNS);
        tagPanel = new JPanel();
        tagPanel.add(tagLabel);
        tagPanel.add(tagTextField);

        centerPanel = new JPanel();
        centerPanel.setLayout(new BoxLayout(centerPanel, BoxLayout.Y_AXIS));
        centerPanel.add(wordPanel);
        centerPanel.add(translationsPanel);
        centerPanel.add(remarkPanel);
        centerPanel.add(typePanel);
        centerPanel.add(tagPanel);

        contentPane = new JPanel();
        contentPane.setLayout(new BorderLayout());
        contentPane.add(centerPanel, "Center");
        contentPane.add(buttonsPanel, "South");

        setContentPane(contentPane);

        pack();
        show();
    }

}
