/*
 * EditorFrame.java     1.0     2001/12/27
 *
 * Copyright (c) 2001 Andreas Dangel <a.dangel@gmx.de>
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package editor;

import libraries.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

public class EditorFrame extends JFrame {

    private VocabularyTree vocabularyTree;
    private boolean saved = true;

    private JPanel contentPane;
    private JScrollPane treeView;
    private JTree tree;

    private JMenuBar menubar;
    private JMenu fileMenu;
    private JMenuItem saveMenuItem;
    private JMenuItem quitMenuItem;

    private JLabel statusbar;

    private JPanel buttonsPanel;
    private JButton addLessonButton;
    private JButton addVocableButton;
    private JButton editSelectionButton;
    private JButton removeSelectionButton;
    private JButton repaintButton;
    private JButton upButton;
    private JButton downButton;
    private JButton leftButton;
    private JButton rightButton;




    EditorFrame(VocabularyTree voctree) {
        super("Editor");

        vocabularyTree = voctree;
        setTitle(getNewTitle());

        setJMenuBar(createJMenuBar());

        treeView = new JScrollPane(vocabularyTree);

        statusbar = new JLabel("statusbar");

        buttonsPanel = createButtonsPanel();

        contentPane = new JPanel();
        contentPane.setLayout(new BorderLayout());
        contentPane.add(treeView, "Center");
        contentPane.add(statusbar, "South");
        contentPane.add(buttonsPanel, "East");

        setContentPane(contentPane);

        addWindowListener(Editor.editorWindowListener);
    }

    private JMenuBar createJMenuBar() {
        menubar = new JMenuBar();

        fileMenu = new JMenu("File");
        fileMenu.setMnemonic('F');

        saveMenuItem = new JMenuItem("Save", 'q');
        saveMenuItem.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_S, ActionEvent.CTRL_MASK));
        saveMenuItem.addActionListener(Editor.editorActionListener);

        quitMenuItem = new JMenuItem("Quit", 'q');
        quitMenuItem.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_Q, ActionEvent.CTRL_MASK));
        quitMenuItem.addActionListener(Editor.editorActionListener);

        fileMenu.add(saveMenuItem);
        fileMenu.addSeparator();
        fileMenu.add(quitMenuItem);
        menubar.add(fileMenu);

        return menubar;
    }

    private JPanel createButtonsPanel() {
        JPanel buttons;

        addLessonButton = new JButton("addLesson");
        addLessonButton.addActionListener(Editor.editorActionListener);
        addVocableButton = new JButton("addVocable");
        addVocableButton.addActionListener(Editor.editorActionListener);
        editSelectionButton = new JButton("editSelection");
        editSelectionButton.addActionListener(Editor.editorActionListener);
        removeSelectionButton = new JButton("removeSelection");
        removeSelectionButton.addActionListener(Editor.editorActionListener);

        repaintButton = new JButton("repaint");
        repaintButton.addActionListener(Editor.editorActionListener);

        upButton = new JButton("move up");
        upButton.addActionListener(Editor.editorActionListener);
        downButton = new JButton("move down");
        downButton.addActionListener(Editor.editorActionListener);
        leftButton = new JButton("move left");
        leftButton.addActionListener(Editor.editorActionListener);
        rightButton = new JButton("move right");
        rightButton.addActionListener(Editor.editorActionListener);

        buttons = new JPanel();
        buttons.setLayout(new BoxLayout(buttons, BoxLayout.Y_AXIS));
        buttons.add(repaintButton);
        buttons.add(Box.createVerticalGlue());
        buttons.add(upButton);
        buttons.add(leftButton);
        buttons.add(rightButton);
        buttons.add(downButton);
        buttons.add(Box.createVerticalGlue());
        buttons.add(addLessonButton);
        buttons.add(addVocableButton);
        buttons.add(Box.createVerticalStrut(15));
        buttons.add(editSelectionButton);
        buttons.add(Box.createVerticalStrut(15));
        buttons.add(removeSelectionButton);

        return buttons;
    }

    private String getNewTitle() {
        if (saved) {
            return "Editor - " + vocabularyTree.getFileName();
        } else {
            return "Editor -*- " + vocabularyTree.getFileName();
        }
    }

    public void setSaved(boolean flag) {
        saved = flag;
        setTitle(getNewTitle());
    }

    public boolean getSaved() {
        return saved;
    }
}