/*
 * TrainerFrame.java     1.0     2001/12/27
 *
 * Copyright (c) 2001 Andreas Dangel <a.dangel@gmx.de>
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package trainer;

import libraries.*;
import java.awt.BorderLayout;
import java.awt.event.*;
import javax.swing.*;

public class TrainerFrame extends JFrame {

    private String filename;
    private String lessonName;

    private JPanel contentPane;
    private Box mainBox;
    private Box vocableBox;
    private Box translationsBox;
    private Box southPanel;


    private JTextField vocableEdit;
    private JTextArea translationsArea;
    private JLabel remarkLabel;
    private JLabel correctionsLabel;
    private JButton actionButton;

    private JMenuBar menubar;
    private JMenu fileMenu;
    private JMenu settingsMenu;
    private JMenuItem quitMenuItem;
    private JMenuItem selectMenuItem;
    private JMenuItem setMenuItem;


    public TrainerLesson lesson;
    private Vocable voc;


    public TrainerFrame(String f, String l) {
        super();
        filename = f;
	lessonName = l;

        lesson = new TrainerLesson(filename, lessonName);

        setTitle(getNewTitle());

        setJMenuBar(createJMenuBar());


        vocableEdit = new JTextField();
	translationsArea = new JTextArea();

        contentPane = new JPanel();
	contentPane.setLayout(new BorderLayout());

        mainBox = new Box(BoxLayout.X_AXIS);
        vocableBox = new Box(BoxLayout.Y_AXIS);
	translationsBox = new Box(BoxLayout.Y_AXIS);
	
	vocableBox.add(new JLabel("Vocable:"));
	vocableBox.add(vocableEdit);
        vocableBox.add(Box.createVerticalGlue());

	translationsBox.add(new JLabel("Translations: (only one per line)"));
	translationsBox.add(new JScrollPane(translationsArea));
	translationsBox.add(Box.createVerticalGlue());

	mainBox.add(vocableBox);
	mainBox.add(translationsBox);

 
        remarkLabel = new JLabel("Remark:...");
	correctionsLabel = new JLabel("Corrections:...");
	actionButton = new JButton("Start...");
	actionButton.addActionListener(Trainer.trainerFrameActionListener);

        southPanel = new Box(BoxLayout.Y_AXIS);
	southPanel.add(remarkLabel);
	southPanel.add(correctionsLabel);
	southPanel.add(actionButton);
	
        contentPane.add(mainBox, "Center");
	contentPane.add(southPanel, "South");

        setContentPane(contentPane);
        addWindowListener(Trainer.trainerFrameWindowListener);

        pack();
    }

    private JMenuBar createJMenuBar() {
        menubar = new JMenuBar();

        fileMenu = new JMenu("File");
	fileMenu.setMnemonic('F');
	
	selectMenuItem = new JMenuItem("Select lessons...", 's');
	selectMenuItem.addActionListener(Trainer.trainerFrameActionListener);

	quitMenuItem = new JMenuItem("Quit", 'q');
	quitMenuItem.addActionListener(Trainer.trainerFrameActionListener);

	settingsMenu = new JMenu("Settings");
	settingsMenu.setMnemonic('S');
	
        setMenuItem = new JMenuItem("Set...", 's');
	setMenuItem.addActionListener(Trainer.trainerFrameActionListener);

	fileMenu.add(selectMenuItem);
	fileMenu.addSeparator();
	fileMenu.add(quitMenuItem);

        settingsMenu.add(setMenuItem);

	menubar.add(fileMenu);
	menubar.add(settingsMenu);

	return menubar;
    }

    private String getNewTitle() {
        return "Trainer - " + filename;
    }

    public void setActionButton(String title) {
        actionButton.setText(title);
    }

    public void showNext() {
        voc = lesson.next();
	if (voc != null) {
  	    vocableEdit.setText(voc.getWord());
	    //translationsArea.setText(voc.getTranslations().getText());
	    translationsArea.setText("");
	    remarkLabel.setText("Remark: " + voc.getRemark());
	    correctionsLabel.setText("Corrections:");
	} else {
	    actionButton.setText("Start...");
	    lesson.resetCounter();
	}
    }

    public void correct() {
        if (voc == null) {
	    return;
	}

        StringList translations = new StringList();
	String correct = "";
	
	translations.setText(translationsArea.getText());
	if (voc.getTranslations().equals(translations)) {
            correct = "Corrections: RIGHT!  ";
	} else {
	    correct = "Corrections: WRONG!  ";
	}
	
	for (int i = 0; i < voc.getTranslations().size(); i++) {
	    correct += "|" + voc.getTranslations().get(i);
	}
	correct += "|";

	correctionsLabel.setText(correct);
	
    }
}
